@@ -4,22 +4,18 @@
 #' @param path path for the  database
 #' @return the path of the database
 #' @author Kai Guo
-#' @examples
-#' \donttest{
-#' preRef(ref_db="silva",path=tempdir())
-#' }
 #' @export
 preRef<-function(ref_db,path="."){
     if (ref_db == "rdp"){
         ifelse(!file.exists(paste0(path,"/rdp_train_set_16.fa.gz")),
         download.file(url = "https://zenodo.org/record/801828/files/rdp_train_set_16.fa.gz?download=1",
                      destfile = file.path(paste0(path, "/rdp_train_set_16.fa.gz")),
-                     method = "auto"),
+                     method = "libcurl", timeout = 1200),
        FALSE);
        ifelse(!file.exists(paste0(path,"/rdp_species_assignment_16.fa.gz")),
        download.file(url = "https://zenodo.org/record/801828/files/rdp_species_assignment_16.fa.gz?download=1",
                      destfile = file.path(paste0(path, "/rdp_species_assignment_16.fa.gz")),
-                     method = "auto"),
+                     method = "libcurl", timeout = 1200),
        FALSE);
         message("Database: ")
         message(paste0(path,"/rdp_train_set_16.fa.gz"))
@@ -28,21 +24,21 @@ preRef<-function(ref_db,path="."){
             ifelse(!file.exists(paste0(path,"/silva_nr99_v138_train_set.fa.gz")),
             download.file(url = "https://zenodo.org/record/4587955/files/silva_nr99_v138.1_train_set.fa.gz?download=1",
                          destfile = file.path(paste0(path, "/silva_nr99_v138_train_set.fa.gz")),
-                         method = "auto"),
+                         method = "libcurl", timeout = 1800),
            FALSE);
-           ifelse(!file.exists(paste0(path,"/silva_species_assignment_v138.fa.gz?")),
+           ifelse(!file.exists(paste0(path,"/silva_species_assignment_v138.fa.gz")),
            download.file(url = 'https://zenodo.org/record/4587955/files/silva_species_assignment_v138.1.fa.gz?download=1',
                          destfile = file.path(paste0(path,"/silva_species_assignment_v138.fa.gz")),
-                         method = 'auto'),
+                         method = 'libcurl', timeout = 1800),
            FALSE);
           message("Database: ")
           message(paste0(path,"/silva_nr99_v138_train_set.fa.gz"))
           message(paste0(path, "/silva_species_assignment_v138.fa.gz"))
     } else {
-           ifelse(!dir.exists(paste0(path,"/gg_13_8_train_set_97.fa.gz")),
+           ifelse(!file.exists(paste0(path,"/gg_13_8_train_set_97.fa.gz")),
            download.file(url = "https://zenodo.org/record/158955/files/gg_13_8_train_set_97.fa.gz?download=1",
                          destfile = file.path(paste0(path, "/gg_13_8_train_set_97.fa.gz")),
-                         method = "auto"),
+                         method = "libcurl", timeout = 1200),
            FALSE);
     message("Database:  ")
     message(paste0(path,"/gg_13_8_train_set_97.fa.gz"))
